@@ -1,6 +1,5 @@
 package Test::Cukes::Feature;
-use Any::Moose;
-use 5.010;
+use Moose;
 
 use Test::Cukes::Scenario;
 
@@ -53,5 +52,5 @@ sub BUILDARGS {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Any::Moose;
+no Moose;
 1;
